pub fn worker_threads_for_available(
configured_threads: Option<usize>,
available_threads: usize,
) -> usizeExpand description
Caps an explicit positive worker count to available parallelism, or uses half the available threads with a minimum target of two.